[![PyPI version](https://badge.fury.io/py/easys-ordermanager.svg)](https://badge.fury.io/py/easys-ordermanager)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/Lektor.svg)](https://pypi.org/project/easys-ordermanager/)

# EasyS order manager API

Tested against
- Python: [3.6, 3.7, 3.8, 3.9]
- Django: [2.2.19, 3.0.13, 3.1.7]
- Django Rest Framework: [3.10.3, 3.11.2, 3.12.2] (except DRF 3.10 on Django 3.1)

See .github/workflows/workflow.yml for more details
